@@ -1,6 +1,7 @@
 import pytest
-from _pytest import runner
 from _pytest import python
+from _pytest import runner
+
 
 class TestOEJSKITSpecials:
     def test_funcarg_non_pycollectobj(self, testdir): # rough jstests usage
@@ -14,7 +15,9 @@ class TestOEJSKITSpecials:
                     return self.fspath, 3, "xyz"
         """)
         modcol = testdir.getmodulecol("""
-            def pytest_funcarg__arg1(request):
+            import pytest
+            @pytest.fixture
+            def arg1(request):
                 return 42
             class MyClass:
                 pass
@@ -42,7 +45,8 @@ class TestOEJSKITSpecials:
             @pytest.fixture(autouse=True)
             def hello():
                 pass
-            def pytest_funcarg__arg1(request):
+            @pytest.fixture
+            def arg1(request):
                 return 42
             class MyClass:
                 pass
@@ -72,7 +76,7 @@ def test_wrapped_getfslineno():
 
 class TestMockDecoration:
     def test_wrapped_getfuncargnames(self):
-        from _pytest.python import getfuncargnames
+        from _pytest.compat import getfuncargnames
         def wrap(f):
             def func():
                 pass
@@ -85,7 +89,7 @@ class TestMockDecoration:
         assert l == ("x",)
 
     def test_wrapped_getfuncargnames_patching(self):
-        from _pytest.python import getfuncargnames
+        from _pytest.compat import getfuncargnames
         def wrap(f):
             def func():
                 pass
@@ -233,12 +237,12 @@ class TestReRunTests:
         """)
 
 def test_pytestconfig_is_session_scoped():
-    from _pytest.python import pytestconfig
+    from _pytest.fixtures import pytestconfig
     assert pytestconfig._pytestfixturefunction.scope == "session"
 
 
 class TestNoselikeTestAttribute:
-    def test_module(self, testdir):
+    def test_module_with_global_test(self, testdir):
         testdir.makepyfile("""
             __test__ = False
             def test_hello():
@@ -248,7 +252,7 @@ class TestNoselikeTestAttribute:
         assert not reprec.getfailedcollections()
         calls = reprec.getreports("pytest_runtest_logreport")
         assert not calls
-        
+
     def test_class_and_method(self, testdir):
         testdir.makepyfile("""
             __test__ = True
@@ -283,6 +287,35 @@ class TestNoselikeTestAttribute:
         assert len(call.items) == 1
         assert call.items[0].cls.__name__ == "TC"
 
+    def test_class_with_nasty_getattr(self, testdir):
+        """Make sure we handle classes with a custom nasty __getattr__ right.
+
+        With a custom __getattr__ which e.g. returns a function (like with a
+        RPC wrapper), we shouldn't assume this meant "__test__ = True".
+        """
+        # https://github.com/pytest-dev/pytest/issues/1204
+        testdir.makepyfile("""
+            class MetaModel(type):
+
+                def __getattr__(cls, key):
+                    return lambda: None
+
+
+            BaseModel = MetaModel('Model', (), {})
+
+
+            class Model(BaseModel):
+
+                __metaclass__ = MetaModel
+
+                def test_blah(self):
+                    pass
+        """)
+        reprec = testdir.inline_run()
+        assert not reprec.getfailedcollections()
+        call = reprec.getcalls("pytest_collection_modifyitems")[0]
+        assert not call.items
+
 
 @pytest.mark.issue351
 class TestParameterize:
