@@ -96,6 +96,14 @@ class TestMetafunc:
         pytest.raises(ValueError, lambda: metafunc.parametrize("y", [5,6]))
         pytest.raises(ValueError, lambda: metafunc.parametrize("y", [5,6]))
 
+    def test_parametrize_bad_scope(self, testdir):
+        def func(x): pass
+        metafunc = self.Metafunc(func)
+        try:
+            metafunc.parametrize("x", [1], scope='doggy')
+        except ValueError as ve:
+            assert "has an unsupported scope value 'doggy'" in str(ve)
+
     def test_parametrize_and_id(self):
         def func(x, y): pass
         metafunc = self.Metafunc(func)
@@ -105,6 +113,14 @@ class TestMetafunc:
         ids = [x.id for x in metafunc._calls]
         assert ids == ["basic-abc", "basic-def", "advanced-abc", "advanced-def"]
 
+    def test_parametrize_and_id_unicode(self):
+        """Allow unicode strings for "ids" parameter in Python 2 (##1905)"""
+        def func(x): pass
+        metafunc = self.Metafunc(func)
+        metafunc.parametrize("x", [1, 2], ids=[u'basic', u'advanced'])
+        ids = [x.id for x in metafunc._calls]
+        assert ids == [u"basic", u"advanced"]
+
     def test_parametrize_with_wrong_number_of_ids(self, testdir):
         def func(x, y): pass
         metafunc = self.Metafunc(func)
