@@ -5,24 +5,28 @@ from _pytest.config import getcfg, get_common_ancestor, determine_setup
 from _pytest.main import EXIT_NOTESTSCOLLECTED
 
 class TestParseIni:
-    def test_getcfg_and_config(self, testdir, tmpdir):
+
+    @pytest.mark.parametrize('section, filename',
+                             [('pytest', 'pytest.ini'), ('tool:pytest', 'setup.cfg')])
+    def test_getcfg_and_config(self, testdir, tmpdir, section, filename):
         sub = tmpdir.mkdir("sub")
         sub.chdir()
-        tmpdir.join("setup.cfg").write(_pytest._code.Source("""
-            [pytest]
+        tmpdir.join(filename).write(_pytest._code.Source("""
+            [{section}]
             name = value
-        """))
-        rootdir, inifile, cfg = getcfg([sub], ["setup.cfg"])
+        """.format(section=section)))
+        rootdir, inifile, cfg = getcfg([sub])
         assert cfg['name'] == "value"
         config = testdir.parseconfigure(sub)
         assert config.inicfg['name'] == 'value'
 
-    def test_getcfg_empty_path(self, tmpdir):
-        getcfg([''], ['setup.cfg']) #happens on py.test ""
+    def test_getcfg_empty_path(self):
+        """correctly handle zero length arguments (a la pytest '')"""
+        getcfg([''])
 
     def test_append_parse_args(self, testdir, tmpdir, monkeypatch):
         monkeypatch.setenv('PYTEST_ADDOPTS', '--color no -rs --tb="short"')
-        tmpdir.join("setup.cfg").write(_pytest._code.Source("""
+        tmpdir.join("pytest.ini").write(_pytest._code.Source("""
             [pytest]
             addopts = --verbose
         """))
@@ -31,10 +35,6 @@ class TestParseIni:
         assert config.option.reportchars == 's'
         assert config.option.tbstyle == 'short'
         assert config.option.verbose
-        #config = testdir.Config()
-        #args = [tmpdir,]
-        #config._preparse(args, addopts=False)
-        #assert len(args) == 1
 
     def test_tox_ini_wrong_version(self, testdir):
         testdir.makefile('.ini', tox="""
@@ -47,12 +47,16 @@ class TestParseIni:
             "*tox.ini:2*requires*9.0*actual*"
         ])
 
-    @pytest.mark.parametrize("name", "setup.cfg tox.ini pytest.ini".split())
-    def test_ini_names(self, testdir, name):
+    @pytest.mark.parametrize("section, name", [
+        ('tool:pytest', 'setup.cfg'),
+        ('pytest', 'tox.ini'),
+        ('pytest', 'pytest.ini')],
+    )
+    def test_ini_names(self, testdir, name, section):
         testdir.tmpdir.join(name).write(py.std.textwrap.dedent("""
-            [pytest]
+            [{section}]
             minversion = 1.0
-        """))
+        """.format(section=section)))
         config = testdir.parseconfig()
         assert config.getini("minversion") == "1.0"
 
@@ -365,7 +369,7 @@ def test_options_on_small_file_do_not_blow_up(testdir):
     """)
 
     for opts in ([], ['-l'], ['-s'], ['--tb=no'], ['--tb=short'],
-                 ['--tb=long'], ['--fulltrace'], ['--nomagic'],
+                 ['--tb=long'], ['--fulltrace'],
                  ['--traceconfig'], ['-v'], ['-v', '-v']):
         runfiletest(opts + [path])
 
@@ -373,10 +377,14 @@ def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
     pkg_resources = pytest.importorskip("pkg_resources")
     def my_iter(name):
         assert name == "pytest11"
+        class Dist:
+            project_name = 'spam'
+            version = '1.0'
+            def _get_metadata(self, name):
+                return ['foo.txt,sha256=abc,123']
         class EntryPoint:
             name = "mytestplugin"
-            class dist:
-                pass
+            dist = Dist()
             def load(self):
                 class PseudoPlugin:
                     x = 42
@@ -391,12 +399,40 @@ def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
     plugin = config.pluginmanager.getplugin("mytestplugin")
     assert plugin.x == 42
 
+
+def test_setuptools_importerror_issue1479(testdir, monkeypatch):
+    pkg_resources = pytest.importorskip("pkg_resources")
+    def my_iter(name):
+        assert name == "pytest11"
+        class Dist:
+            project_name = 'spam'
+            version = '1.0'
+            def _get_metadata(self, name):
+                return ['foo.txt,sha256=abc,123']
+        class EntryPoint:
+            name = "mytestplugin"
+            dist = Dist()
+            def load(self):
+                raise ImportError("Don't hide me!")
+        return iter([EntryPoint()])
+
+    monkeypatch.setattr(pkg_resources, 'iter_entry_points', my_iter)
+    with pytest.raises(ImportError):
+        testdir.parseconfig()
+
+
 def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch):
     pkg_resources = pytest.importorskip("pkg_resources")
     def my_iter(name):
         assert name == "pytest11"
+        class Dist:
+            project_name = 'spam'
+            version = '1.0'
+            def _get_metadata(self, name):
+                return ['foo.txt,sha256=abc,123']
         class EntryPoint:
             name = "mytestplugin"
+            dist = Dist()
             def load(self):
                 assert 0, "should not arrive here"
         return iter([EntryPoint()])
@@ -451,7 +487,8 @@ def test_consider_args_after_options_for_rootdir_and_inifile(testdir, args):
             args[i] = d1
         elif arg == 'dir2':
             args[i] = d2
-    result = testdir.runpytest(*args)
+    with root.as_cwd():
+        result = testdir.runpytest(*args)
     result.stdout.fnmatch_lines(['*rootdir: *myroot, inifile: '])
 
 
@@ -485,9 +522,13 @@ def test_load_initial_conftest_last_ordering(testdir):
     pm.register(m)
     hc = pm.hook.pytest_load_initial_conftests
     l = hc._nonwrappers + hc._wrappers
-    assert l[-1].function.__module__ == "_pytest.capture"
-    assert l[-2].function == m.pytest_load_initial_conftests
-    assert l[-3].function.__module__ == "_pytest.config"
+    expected = [
+        "_pytest.config",
+        'test_config',
+        '_pytest.capture',
+    ]
+    assert [x.function.__module__ for x in l] == expected
+
 
 class TestWarning:
     def test_warn_config(self, testdir):
@@ -507,33 +548,38 @@ class TestWarning:
         reprec = testdir.inline_run()
         reprec.assertoutcome(passed=1)
 
-    def test_warn_on_test_item_from_request(self, testdir):
+    def test_warn_on_test_item_from_request(self, testdir, request):
         testdir.makepyfile("""
             import pytest
 
             @pytest.fixture
             def fix(request):
                 request.node.warn("T1", "hello")
+
             def test_hello(fix):
                 pass
         """)
-        result = testdir.runpytest()
+        result = testdir.runpytest("--disable-pytest-warnings")
         assert result.parseoutcomes()["pytest-warnings"] > 0
         assert "hello" not in result.stdout.str()
 
-        result = testdir.runpytest("-rw")
+        result = testdir.runpytest()
         result.stdout.fnmatch_lines("""
             ===*pytest-warning summary*===
-            *WT1*test_warn_on_test_item*:5*hello*
+            *WT1*test_warn_on_test_item*:7 hello*
         """)
 
 class TestRootdir:
     def test_simple_noini(self, tmpdir):
         assert get_common_ancestor([tmpdir]) == tmpdir
-        assert get_common_ancestor([tmpdir.mkdir("a"), tmpdir]) == tmpdir
-        assert get_common_ancestor([tmpdir, tmpdir.join("a")]) == tmpdir
+        a = tmpdir.mkdir("a")
+        assert get_common_ancestor([a, tmpdir]) == tmpdir
+        assert get_common_ancestor([tmpdir, a]) == tmpdir
         with tmpdir.as_cwd():
             assert get_common_ancestor([]) == tmpdir
+            no_path = tmpdir.join('does-not-exist')
+            assert get_common_ancestor([no_path]) == tmpdir
+            assert get_common_ancestor([no_path.join('a')]) == tmpdir
 
     @pytest.mark.parametrize("name", "setup.cfg tox.ini pytest.ini".split())
     def test_with_ini(self, tmpdir, name):
@@ -568,7 +614,8 @@ class TestRootdir:
         assert inifile is None
         assert inicfg == {}
 
-    def test_nothing(self, tmpdir):
+    def test_nothing(self, tmpdir, monkeypatch):
+        monkeypatch.chdir(str(tmpdir))
         rootdir, inifile, inicfg = determine_setup(None, [tmpdir])
         assert rootdir == tmpdir
         assert inifile is None
@@ -578,3 +625,108 @@ class TestRootdir:
         inifile = tmpdir.ensure("pytest.ini")
         rootdir, inifile, inicfg = determine_setup(inifile, [tmpdir])
         assert rootdir == tmpdir
+
+
+class TestOverrideIniArgs:
+    @pytest.mark.parametrize("name", "setup.cfg tox.ini pytest.ini".split())
+    def test_override_ini_names(self, testdir, name):
+        testdir.tmpdir.join(name).write(py.std.textwrap.dedent("""
+            [pytest]
+            custom = 1.0"""))
+        testdir.makeconftest("""
+            def pytest_addoption(parser):
+                parser.addini("custom", "")""")
+        testdir.makepyfile("""
+            def test_pass(pytestconfig):
+                ini_val = pytestconfig.getini("custom")
+                print('\\ncustom_option:%s\\n' % ini_val)""")
+
+        result = testdir.runpytest("--override-ini", "custom=2.0", "-s")
+        assert result.ret == 0
+        result.stdout.fnmatch_lines(["custom_option:2.0"])
+
+        result = testdir.runpytest("--override-ini", "custom=2.0",
+                                   "--override-ini=custom=3.0", "-s")
+        assert result.ret == 0
+        result.stdout.fnmatch_lines(["custom_option:3.0"])
+
+
+    def test_override_ini_pathlist(self, testdir):
+        testdir.makeconftest("""
+            def pytest_addoption(parser):
+                parser.addini("paths", "my new ini value", type="pathlist")""")
+        testdir.makeini("""
+            [pytest]
+            paths=blah.py""")
+        testdir.makepyfile("""
+            import py.path
+            def test_pathlist(pytestconfig):
+                config_paths = pytestconfig.getini("paths")
+                print(config_paths)
+                for cpf in config_paths:
+                    print('\\nuser_path:%s' % cpf.basename)""")
+        result = testdir.runpytest("--override-ini",
+                                   'paths=foo/bar1.py foo/bar2.py', "-s")
+        result.stdout.fnmatch_lines(["user_path:bar1.py",
+                                     "user_path:bar2.py"])
+
+    def test_override_multiple_and_default(self, testdir):
+        testdir.makeconftest("""
+            def pytest_addoption(parser):
+                addini = parser.addini
+                addini("custom_option_1", "", default="o1")
+                addini("custom_option_2", "", default="o2")
+                addini("custom_option_3", "", default=False, type="bool")
+                addini("custom_option_4", "", default=True, type="bool")""")
+        testdir.makeini("""
+            [pytest]
+            custom_option_1=custom_option_1
+            custom_option_2=custom_option_2""")
+        testdir.makepyfile("""
+            def test_multiple_options(pytestconfig):
+                prefix = "custom_option"
+                for x in range(1, 5):
+                    ini_value=pytestconfig.getini("%s_%d" % (prefix, x))
+                    print('\\nini%d:%s' % (x, ini_value))""")
+        result = testdir.runpytest(
+            "--override-ini", 'custom_option_1=fulldir=/tmp/user1',
+            'custom_option_2=url=/tmp/user2?a=b&d=e',
+            "-o", 'custom_option_3=True',
+            "-o", 'custom_option_4=no', "-s")
+        result.stdout.fnmatch_lines(["ini1:fulldir=/tmp/user1",
+                                     "ini2:url=/tmp/user2?a=b&d=e",
+                                     "ini3:True",
+                                     "ini4:False"])
+
+    def test_with_arg_outside_cwd_without_inifile(self, tmpdir, monkeypatch):
+        monkeypatch.chdir(str(tmpdir))
+        a = tmpdir.mkdir("a")
+        b = tmpdir.mkdir("b")
+        rootdir, inifile, inicfg = determine_setup(None, [a, b])
+        assert rootdir == tmpdir
+        assert inifile is None
+
+    def test_with_arg_outside_cwd_with_inifile(self, tmpdir):
+        a = tmpdir.mkdir("a")
+        b = tmpdir.mkdir("b")
+        inifile = a.ensure("pytest.ini")
+        rootdir, parsed_inifile, inicfg = determine_setup(None, [a, b])
+        assert rootdir == a
+        assert inifile == parsed_inifile
+
+    @pytest.mark.parametrize('dirs', ([], ['does-not-exist'],
+                                      ['a/does-not-exist']))
+    def test_with_non_dir_arg(self, dirs, tmpdir):
+        with tmpdir.ensure(dir=True).as_cwd():
+            rootdir, inifile, inicfg = determine_setup(None, dirs)
+            assert rootdir == tmpdir
+            assert inifile is None
+
+    def test_with_existing_file_in_subdir(self, tmpdir):
+        a = tmpdir.mkdir("a")
+        a.ensure("exist")
+        with tmpdir.as_cwd():
+            rootdir, inifile, inicfg = determine_setup(None, ['a/exist'])
+            assert rootdir == tmpdir
+            assert inifile is None
+
